@@ -53,7 +53,7 @@
 #include <kurl.h>
 #include <kcomponentdata.h>
 
-#include <QtDBus/QDBusConnection>
+#include <kdbusconnectionpool.h>
 #include <QtDBus/QDBusMessage>
 
 using namespace Soprano;
@@ -275,7 +275,7 @@ bool Nepomuk2::ResourceData::store()
                           << QString() << QString()
                           << KGlobal::mainComponent().componentName() );
 
-        QDBusConnection bus = QDBusConnection::sessionBus();
+        QDBusConnection bus = KDBusConnectionPool::threadConnection();
         QDBusMessage reply = bus.call( msg );
         if( reply.type() == QDBusMessage::ErrorMessage ) {
             //TODO: Set the error somehow
@@ -418,7 +418,7 @@ void Nepomuk2::ResourceData::setProperty( const QUrl& uri, const Nepomuk2::Varia
                           << QVariant(DBus::normalizeVariantList(varList))
                           << KGlobal::mainComponent().componentName() );
 
-        QDBusConnection bus = QDBusConnection::sessionBus();
+        QDBusConnection bus = KDBusConnectionPool::threadConnection();
         QDBusMessage reply = bus.call( msg );
         if( reply.type() == QDBusMessage::ErrorMessage ) {
             //TODO: Set the error somehow
@@ -473,7 +473,7 @@ void Nepomuk2::ResourceData::addProperty( const QUrl& uri, const Nepomuk2::Varia
                           << QVariant(DBus::normalizeVariantList(varList))
                           << KGlobal::mainComponent().componentName() );
 
-        QDBusConnection bus = QDBusConnection::sessionBus();
+        QDBusConnection bus = KDBusConnectionPool::threadConnection();
         QDBusMessage reply = bus.call( msg );
         if( reply.type() == QDBusMessage::ErrorMessage ) {
             //TODO: Set the error somehow
@@ -507,7 +507,7 @@ void Nepomuk2::ResourceData::removeProperty( const QUrl& uri )
                           << DBus::convertUri(uri)
                           << KGlobal::mainComponent().componentName() );
 
-        QDBusConnection bus = QDBusConnection::sessionBus();
+        QDBusConnection bus = KDBusConnectionPool::threadConnection();
         QDBusMessage reply = bus.call( msg );
         if( reply.type() == QDBusMessage::ErrorMessage ) {
             //TODO: Set the error somehow
@@ -540,7 +540,7 @@ void Nepomuk2::ResourceData::remove( bool recursive )
                           << 0 /* no flags */
                           << KGlobal::mainComponent().componentName());
 
-        QDBusConnection bus = QDBusConnection::sessionBus();
+        QDBusConnection bus = KDBusConnectionPool::threadConnection();
         QDBusMessage reply = bus.call( msg );
         if( reply.type() == QDBusMessage::ErrorMessage ) {
             //TODO: Set the error somehow
