@@ -51,8 +51,9 @@ namespace {
 Nepomuk2::FileIndexerConfig* Nepomuk2::FileIndexerConfig::s_self = 0;
 
 Nepomuk2::FileIndexerConfig::FileIndexerConfig(QObject* parent)
-    : QObject(parent),
-      m_config( "nepomukstrigirc" )
+    : QObject(parent)
+    , m_config( "nepomukstrigirc" )
+    , m_indexHidden(false)
 {
     if(!s_self) {
         s_self = this;
@@ -134,7 +135,6 @@ QStringList Nepomuk2::FileIndexerConfig::excludeFilters() const
 bool Nepomuk2::FileIndexerConfig::indexHiddenFilesAndFolders() const
 {
     return m_indexHidden;
-    return m_config.group( "General" ).readEntry( "index hidden folders", false );
 }
 
 
@@ -174,7 +174,8 @@ bool Nepomuk2::FileIndexerConfig::shouldBeIndexed( const QString& path ) const
 bool Nepomuk2::FileIndexerConfig::shouldFolderBeWatched( const QString& path ) const
 {
     // do not watch folders in the exclude filters
-    if(!shouldFileBeIndexed( path.split('/', QString::SkipEmptyParts).last() ))
+    QStringList cmpts = path.split('/', QString::SkipEmptyParts);
+    if( cmpts.isEmpty() || !shouldFileBeIndexed( cmpts.last() ) )
         return false;
     return true;
 }
