@@ -21,6 +21,7 @@
 
 #include <Soprano/BackendSettings>
 #include <Soprano/FilterModel>
+#include <Soprano/Util/DummyModel>
 
 
 namespace Soprano {
@@ -104,6 +105,8 @@ namespace Nepomuk2 {
         Nepomuk2::DataManagementAdaptor* m_dataManagementAdaptor;
         const Soprano::Backend* m_backend;
 
+        Soprano::Util::DummyModel* m_dummyModel;
+
         // only used during opening
         // ------------------------------------------
         ModelCopyJob* m_modelCopyJob;
